import random

def udirdagch_songo(ner_degshigchid):
    '''
    Удирдагчыг санамсаргүй байдлаар сонгон буцаана

    Parameters:
        ner_degshigchid(list): Нэр дэвшиж буй намууд
    Return:
        string: Сонгогдсон нэр
    '''
    return random.choice(ner_degshigchid)


import setuptools 
from pathlib import Path

setuptools.setup(
    name="udirdagchpython",version="1.0.0",
    long_description=Path("README.md").read_text(),
    packages=setuptools.find_packages(exclude=[".vscode", "turshikh.py","tests", "data"])
)